fisx: fisx_elements.h File Reference

fisx

Classes | Macros
fisx_elements.h File Reference

Elements properties. More...

`#include <string>`
`#include <vector>`
`#include <map>`
`#include "fisx_simplespecfile.h"`
`#include "fisx_element.h"`
`#include "fisx_epdl97.h"`
`#include "fisx_material.h"`

Go to the source code of this file.

## Classes
class | fisx::Elements
| Class handling the physical properties. More...

## Macros
#define | FISX_DATA_DIR ""

## Detailed Description

Elements properties.

Author
  V.A. Sole

Version
  1.0